Index: sm/trunk/etc/cielo.rc
===================================================================
--- /issm/trunk/etc/cielo.rc	(revision 113)
+++ 	(revision )
@@ -1,73 +1,0 @@
-begin
-
-#This file sets default platform settings used by Cielo. 
-#This file should always start with begin, and end with end. 
-#Comments start with #. 
-
-#The syntax to add a computational server is the following: 
-#server_name=foobar
-#server_ip=127.0.0.1
-#server_port=1025
-#server_tunneling=yes:1025
-
-#Just uncomment the 4 lines above if you want to add a server 
-#with hostname foobar, ip 127.0.0.1, listening on port 1025 and 
-#using ssh tunneling on local port 1025. 
-#The server_name can be of any form, provided it's a string. Using 
-#the network hostname is good practice.
-#The server_ip needs to be of the format a.b.c.d where a,b,c,d are 
-#numbers from 0 to 255. 
-#The server_port is any valid port number on the current platform (usually, 
-#using ports 1025 and higher is good practice, as those ports 
-#are dedicated for users).
-#server_tunneling can be either yes, or no. It sets the ssh tunneling option
-#for secure connections. If set to yes, it needs to be followed by the 
-#local port that is ssh tunneled to the server port. Don't forget the semi colon.
-#Final remark on including server settings: do not include spaces 
-#between a field, the '=' sign and its value. Do not also include trailing spaces
-#at the end of a line.
-
-server_name=cosmos
-server_ip=128.149.134.43
-server_port=1025
-server_tunneling=yes:1025
-server_codepath=/home/larour/tier2_ice/server_delivery
-server_executionpath=/scratch/larour/Testing/AGU_2008
-
-server_name=mustang
-server_ip=128.149.26.108
-server_port=1030
-server_tunneling=no
-server_codepath=/proj/ice/larour/Ice/tier2_ice/server_delivery
-server_executionpath=/proj/ice/larour/Testing_ice/Execution
-
-server_name=metro
-server_ip=128.149.26.85
-server_port=1025
-server_tunneling=no
-server_codepath=/home/larour/Ice/tier2_ice/server_delivery
-server_executionpath=/home/larour/Testing/Execution
-
-server_name=wilkes
-server_ip=137.79.160.187
-server_port=1025
-server_tunneling=no
-server_codepath=/u/wilkes-r1b/larour/Ice/ice1.proto/bin
-server_executionpath=/home/larour/Testing/Execution
-
-server_name=astrid
-server_ip=137.79.160.65
-server_port=1025
-server_tunneling=no
-server_codepath=/u/astrid1/larour/issm-1.0/bin
-server_executionpath=/home/larour/Testing/Execution
-
-server_name=gemini
-server_ip=128.149.134.21
-server_port=1025
-server_tunneling=no
-server_codepath=/home/larour/issm/bin
-server_executionpath=/home/larour/Testing/Execution
-
-
-end
Index: /issm/trunk/etc/issm.rc
===================================================================
--- /issm/trunk/etc/issm.rc	(revision 114)
+++ /issm/trunk/etc/issm.rc	(revision 114)
@@ -0,0 +1,73 @@
+begin
+
+#This file sets default platform settings used by Cielo. 
+#This file should always start with begin, and end with end. 
+#Comments start with #. 
+
+#The syntax to add a computational server is the following: 
+#server_name=foobar
+#server_ip=127.0.0.1
+#server_port=1025
+#server_tunneling=yes:1025
+
+#Just uncomment the 4 lines above if you want to add a server 
+#with hostname foobar, ip 127.0.0.1, listening on port 1025 and 
+#using ssh tunneling on local port 1025. 
+#The server_name can be of any form, provided it's a string. Using 
+#the network hostname is good practice.
+#The server_ip needs to be of the format a.b.c.d where a,b,c,d are 
+#numbers from 0 to 255. 
+#The server_port is any valid port number on the current platform (usually, 
+#using ports 1025 and higher is good practice, as those ports 
+#are dedicated for users).
+#server_tunneling can be either yes, or no. It sets the ssh tunneling option
+#for secure connections. If set to yes, it needs to be followed by the 
+#local port that is ssh tunneled to the server port. Don't forget the semi colon.
+#Final remark on including server settings: do not include spaces 
+#between a field, the '=' sign and its value. Do not also include trailing spaces
+#at the end of a line.
+
+server_name=cosmos
+server_ip=128.149.134.43
+server_port=1025
+server_tunneling=yes:1025
+server_codepath=/home/larour/tier2_ice/server_delivery
+server_executionpath=/scratch/larour/Testing/AGU_2008
+
+server_name=mustang
+server_ip=128.149.26.108
+server_port=1030
+server_tunneling=no
+server_codepath=/proj/ice/larour/Ice/tier2_ice/server_delivery
+server_executionpath=/proj/ice/larour/Testing_ice/Execution
+
+server_name=metro
+server_ip=128.149.26.85
+server_port=1025
+server_tunneling=no
+server_codepath=/home/larour/Ice/tier2_ice/server_delivery
+server_executionpath=/home/larour/Testing/Execution
+
+server_name=wilkes
+server_ip=137.79.160.187
+server_port=1025
+server_tunneling=no
+server_codepath=/u/wilkes-r1b/larour/Ice/ice1.proto/bin
+server_executionpath=/home/larour/Testing/Execution
+
+server_name=astrid
+server_ip=137.79.160.65
+server_port=1025
+server_tunneling=no
+server_codepath=/u/astrid1/larour/issm/trunk/bin
+server_executionpath=/home/larour/Testing/Execution
+
+server_name=gemini
+server_ip=128.149.134.21
+server_port=1025
+server_tunneling=no
+server_codepath=/home/larour/issm/bin
+server_executionpath=/home/larour/Testing/Execution
+
+
+end
Index: /issm/trunk/src/m/classes/public/loadresultsfromcluster.m
===================================================================
--- /issm/trunk/src/m/classes/public/loadresultsfromcluster.m	(revision 113)
+++ /issm/trunk/src/m/classes/public/loadresultsfromcluster.m	(revision 114)
@@ -5,9 +5,9 @@
 %      md=loadresultsfromcluster(md,solutiontype);
 
-%Get cielo.rc location
-cielo_rc_location=which('cielo.rc');
+%Get issm.rc location
+issm_rc_location=which('issm.rc');
 
 %Figure out parameters for this particular cluster
-[codepath,executionpath]=ProcessParallelParametersFromCieloRc(md.cluster,cielo_rc_location);
+[codepath,executionpath]=ProcessParallelParametersFromCieloRc(md.cluster,issm_rc_location);
 
 %if we are running locally, no need to call ssh to recover the logs and results. We figure out by comparing the 
Index: /issm/trunk/src/m/classes/public/peek.m
===================================================================
--- /issm/trunk/src/m/classes/public/peek.m	(revision 113)
+++ /issm/trunk/src/m/classes/public/peek.m	(revision 114)
@@ -7,9 +7,9 @@
 %   See also: QueueJobPeek
 
-%Get cielo.rc location
-cielo_rc_location=which('cielo.rc');
+%Get issm.rc location
+issm_rc_location=which('issm.rc');
 
 %Figure out parameters for this particular cluster
-[codepath,executionpath]=ProcessParallelParametersFromCieloRc(md.cluster,cielo_rc_location);
+[codepath,executionpath]=ProcessParallelParametersFromCieloRc(md.cluster,issm_rc_location);
 
 %peek at the queued job
Index: /issm/trunk/src/m/classes/public/preparerun.m
===================================================================
--- /issm/trunk/src/m/classes/public/preparerun.m	(revision 113)
+++ /issm/trunk/src/m/classes/public/preparerun.m	(revision 114)
@@ -20,9 +20,9 @@
 end
 
-%Get cielo.rc location
-cielo_rc_location=which('cielo.rc');
+%Get issm.rc location
+issm_rc_location=which('issm.rc');
 
 %Figure out parameters for this particular cluster
-[codepath,executionpath]=ProcessParallelParametersFromCieloRc(md.cluster,cielo_rc_location);
+[codepath,executionpath]=ProcessParallelParametersFromCieloRc(md.cluster,issm_rc_location);
 
 %Marshall model data into a binary file.
Index: /issm/trunk/src/m/classes/public/solveparallel.m
===================================================================
--- /issm/trunk/src/m/classes/public/solveparallel.m	(revision 113)
+++ /issm/trunk/src/m/classes/public/solveparallel.m	(revision 114)
@@ -20,9 +20,9 @@
 end
 
-%Get cielo.rc location
-cielo_rc_location=which('cielo.rc');
+%Get issm.rc location
+issm_rc_location=which('issm.rc');
 
 %Figure out parameters for this particular cluster
-[codepath,executionpath]=ProcessParallelParametersFromCieloRc(md.cluster,cielo_rc_location);
+[codepath,executionpath]=ProcessParallelParametersFromCieloRc(md.cluster,issm_rc_location);
 
 %Marshall model data into a binary file.
Index: /issm/trunk/src/m/solutions/ice/debug.m
===================================================================
--- /issm/trunk/src/m/solutions/ice/debug.m	(revision 113)
+++ /issm/trunk/src/m/solutions/ice/debug.m	(revision 114)
@@ -4,5 +4,5 @@
 %   the results of both solutions
 
 %first get this into the cielo code, at the core solution level
 %PetscSynchronizedPrintf(MPI_COMM_WORLD,"Messing up here\n");
 %PetscSynchronizedFlush(MPI_COMM_WORLD);
@@ -14,5 +14,5 @@
 %nicely, if not correct. When everything works, reinstate the try catch.
 
 %an alter is used to modify the core solution in Ice, to stop right after Emg. But for cielo, 
 %we don't have an alter, just use the first 5 lines of this file and put them in the batch 
 %solution.
@@ -61,5 +61,5 @@
 md=solve(md,'diagnostic_horiz','cielo');
 
-cielo_rc_location=which('cielo.rc'); [codepath,executionpath]=ProcessBatchParametersFromCieloRc(md.cluster,cielo_rc_location);
+issm_rc_location=which('issm.rc'); [codepath,executionpath]=ProcessBatchParametersFromCieloRc(md.cluster,issm_rc_location);
 
 pause(5);
@@ -4,5 +4,5 @@
 %   the results of both solutions
 
-%first get this into the cielo code, at the core solution level
+%first get this into the issm code, at the core solution level
 %PetscSynchronizedPrintf(MPI_COMM_WORLD,"Messing up here\n");
 %PetscSynchronizedFlush(MPI_COMM_WORLD);
@@ -14,5 +14,5 @@
 %nicely, if not correct. When everything works, reinstate the try catch.
 
-%an alter is used to modify the core solution in Ice, to stop right after Emg. But for cielo, 
+%an alter is used to modify the core solution in Ice, to stop right after Emg. But for issm, 
 %we don't have an alter, just use the first 5 lines of this file and put them in the batch 
 %solution.
Index: /issm/trunk/src/m/utils/Model/ProcessParallelParametersFromCieloRc.m
===================================================================
--- /issm/trunk/src/m/utils/Model/ProcessParallelParametersFromCieloRc.m	(revision 113)
+++ /issm/trunk/src/m/utils/Model/ProcessParallelParametersFromCieloRc.m	(revision 114)
@@ -1,16 +1,16 @@
-function [server_codepath server_executionpath]=ProcessParallelParametersFromCieloRc(server_name,cielo_rc_location)
-%PROCESSPARALLELPARAMETERSFROMCIELORC - process parallel parameters from cielo
+function [server_codepath server_executionpath]=ProcessParallelParametersFromCieloRc(server_name,issm_rc_location)
+%PROCESSPARALLELPARAMETERSFROMCIELORC - process parallel parameters from issm
 %
 %   This function reads through the cielo_rc_location for server settings (name, ip, port and 
 %   tunneling) used to run parallel solution sequences
 %
 %   Usage:
-%      [server_codepath server_executionpath]=ProcessParallelParametersFromCieloRc(server_name,cielo_rc_location)
+%      [server_codepath server_executionpath]=ProcessParallelParametersFromCieloRc(server_name,issm_rc_location)
 
 lines_per_server=5;
-%open cielo.rc file
-fid=fopen(cielo_rc_location);
+%open issm.rc file
+fid=fopen(issm_rc_location);
 if fid==-1,
-	error('Could not find cielo.rc file in delivery directory');
+	error('Could not find issm.rc file in delivery directory');
 end
 
@@ -20,5 +20,5 @@
 line=fgetl(fid);
 if ~strcmp(line,'begin'),
-	error('cielo.rc file in delivery directory should always start with the begin statement');
+	error('issm.rc file in delivery directory should always start with the begin statement');
 end
 
@@ -33,5 +33,5 @@
 	%Check for end of file
 	if ~ischar(line),
-		error('cielo.rc file in delivery directory should end with an end statement');
+		error('issm.rc file in delivery directory should end with an end statement');
 	end
 	%Ignore empty lines
@@ -64,5 +64,5 @@
 				value=splittedstring{2};
 				if ~strcmp(descriptor,'server_codepath'),
-					error('server settings in cielo.rc don''t follow the correct syntax');
+					error('server settings in issm.rc don''t follow the correct syntax');
 				end
 				server_codepath=value;
@@ -76,5 +76,5 @@
 				value=splittedstring{2};
 				if ~strcmp(descriptor,'server_executionpath'),
-					error('server settings in cielo.rc don''t follow the correct syntax');
+					error('server settings in issm.rc don''t follow the correct syntax');
 				end
 				server_executionpath=value;
@@ -94,5 +94,5 @@
 
 if found==0,
-	error(['ProcessParallelParametersFromCieloRc error message: could not find setting for cluster ' server_name 'in cielo.rc file']);
+	error(['ProcessParallelParametersFromCieloRc error message: could not find setting for cluster ' server_name 'in issm.rc file']);
 end
 
@@ -1,16 +1,16 @@
 %
-%   This function reads through the cielo_rc_location for server settings (name, ip, port and 
+%   This function reads through the issm_rc_location for server settings (name, ip, port and 
 %   tunneling) used to run parallel solution sequences
 %
